@@ -426,7 +426,6 @@ on '.' in attachments."
     (let* ((nums (mew-syntax-nums))
 	   (subdir (mew-attach-expand-path mew-encode-syntax nums))
 	   (attachdir (mew-attachdir))
-	   (buf (generate-new-buffer mew-buffer-prefix))
 	   file filepath recorded)
       ;; attachdir / {subdir/} dir
       (unless (string= subdir "")
@@ -436,9 +435,7 @@ on '.' in attachments."
       (if (null filepath)
 	  (message "Cannot make a file for audio, sorry")
 	(setq file (file-name-nondirectory filepath))
-	(save-excursion
-	  (set-buffer buf)
-	  (mew-erase-buffer)
+	(with-temp-buffer
 	  (condition-case nil
 	      (progn
 		(if (not (y-or-n-p "Are you ready? "))
@@ -458,7 +455,6 @@ on '.' in attachments."
 	     (setq recorded t)
 	     (mew-flet
 	      (write-region (point-min) (point-max) filepath nil 'no-msg)))))
-	(mew-remove-buffer buf)
 	(if recorded
 	    (setq mew-encode-syntax ;; buffer local
 		  (mew-syntax-insert-entry
@@ -711,7 +707,7 @@ Input decryptors' addresses."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
