@@ -372,15 +372,15 @@ Words are separated by '/' and '-'."
 
 (defun mew-split (str sepchar)
   "Return a list of strings splitting STR with SEPCHAR."
- (let ((len (length str)) (start 0) (i 0) ret)
-   (while (< i len)
-     (when (char-equal (aref str i) sepchar)
-       (setq ret (cons (substring str start i) ret))
-       (setq start (1+ i)))
-     (setq i (1+ i)))
-   (if (/= start len)
-       (setq ret (cons (substring str start) ret)))
-   (nreverse ret)))
+  (let ((len (length str)) (start 0) (i 0) ret)
+    (while (< i len)
+      (when (char-equal (aref str i) sepchar)
+	(setq ret (cons (substring str start i) ret))
+	(setq start (1+ i)))
+      (setq i (1+ i)))
+    (if (/= start len)
+	(setq ret (cons (substring str start) ret)))
+    (nreverse ret)))
 
 (defun mew-split-quoted (str sepchar &optional qopen qclose)
   "Return a list of strings splitting STR with SEPCHAR.
@@ -557,8 +557,7 @@ also ignored."
     (mew-string-to-local folder)))
 
 (defun mew-path-to-folder (path)
-  (let ((regex (concat "^" (file-name-as-directory
-			    (expand-file-name mew-mail-path)))))
+  (let ((regex (concat "^" (regexp-quote (file-name-as-directory (expand-file-name mew-mail-path))))))
     (if (string-match regex path)
 	(mew-string-to-local (substring path (match-end 0)))
       path)))
@@ -707,10 +706,24 @@ also ignored."
       (write-region "touched by Mew." nil file nil 'no-msg)
       (mew-set-file-modes file))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Folder spec
+;;;
+
+(defconst mew-folder-spec-type
+  '((regex     . string-match)
+    (recursive . mew-folder-recursive-match)
+    (string    . string=)))
+
+(defsubst mew-folder-spec-func (type)
+  (or (cdr (assq type mew-folder-spec-type)) 'string=))
+
 (defun mew-folder-spec (folder lst str-type lst-type)
   (let ((str-func (mew-folder-spec-func str-type))
 	(lst-func (mew-folder-spec-func lst-type))
 	key keys values ret)
+    (setq folder (mew-folder-folder folder))
     (catch 'loop
       (while lst
 	(setq keys (car (car lst)))
@@ -1432,7 +1445,7 @@ by side-effect."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2002 Mew developing team.
+;; Copyright (C) 1997-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
