@@ -30,12 +30,20 @@
 (defun mew-mime-start-process-sentinel (process event)
   (let* ((al (assoc process mew-process-file-alist))
 	 (file (cdr al)))
+    ;; A launcher program may be executed.
+    ;; The launcher program executes an application according to
+    ;; file's suffix or something.
+    ;; The time when the launcher is finished is not the time when
+    ;; the application is finished. So, we can't delete the temporary
+    ;; file here. Hoping that the file will be deleted when Mew is 
+    ;; finished.
     (if mew-delete-temp-file (mew-delete-file file))
     (setq mew-process-file-alist (delq al mew-process-file-alist))))
 
 (defun mew-mime-call-process (program options file)
   (message "Calling %s..." program)
   (apply 'call-process program file nil nil options)
+  (mew-delete-file file)
   (message "Calling %s...done" program)
   t) ;; to next part
 
@@ -594,11 +602,12 @@
 
 (defun mew-mime-application/msoffice (prog cache begin end &optional parameter)
   (let ((doit t) file1 file2)
-    (condition-case nil
-	(require 'un-define)
-      (file-error
-       (setq doit nil)
-       (mew-elet (insert "To display this, install Mule-UCS for UTF-8.\n"))))
+    (unless mew-internal-utf-8p
+      (condition-case nil
+	  (require 'un-define)
+	(file-error
+	 (setq doit nil)
+	 (mew-elet (insert "To display this, install Mule-UCS for UTF-8.\n")))))
     (unless (mew-which-exec prog)
       (setq doit nil)
       (mew-elet (insert "To display this, install \"" prog "\".\n")))
@@ -624,6 +633,7 @@
 	   (if mew-use-old-wvhtml
 	       (call-process prog nil nil nil file1 file2)
 	     (call-process prog nil nil nil
+			   "--charset=utf-8"
 			   (concat "--targetdir=" (file-name-directory file2))
 			   file1 
 			   (file-name-nondirectory file2)))
@@ -643,7 +653,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2002 Mew developing team.
+;; Copyright (C) 1997-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
