@@ -7,6 +7,33 @@
 
 (require 'mew)
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Port DB
+;;;
+
+(defvar mew-port-db
+  '(("smtp"  .  "25")
+    ;; This is officially assigned to another service (urd) by IANA.
+    ;; IESG will never assign a port number to SMTP over SSL...
+    ("smtps" . "465")
+    ("pop3"  . "110")
+    ("pop3s" . "995")
+    ("nntp"  . "119")
+    ("nntps" . "563")
+    ("imap"  . "143")
+    ("imaps" . "993")))
+
+(defun mew-serv-to-port (serv)
+  (if (string-match "^[0-9]+$" serv)
+      serv
+    (or (cdr (assoc serv mew-port-db)) "0")))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Net folders
+;;;
+
 (defvar mew-pop-folder  "+.pop/%s@%s%%%s")
 (defvar mew-imap-folder "+.imap/%s@%s%%%s")
 (defvar mew-nntp-folder "+.nntp/%s@%s%%%s")
@@ -29,32 +56,43 @@
 ;;; Net status
 ;;;
 
-(defun mew-summary-lock (key status)
+(defun mew-summary-lock (key status &optional secure)
   (setq mew-summary-buffer-process key)
-  (setq mew-summary-buffer-process-status (format " %s" status)))
+  (setq mew-summary-buffer-process-status (format " %s" status))
+  (setq mew-summary-buffer-secure-process secure))
+  
 
 (defun mew-summary-unlock ()
   (setq mew-summary-buffer-process nil)
-  (setq mew-summary-buffer-process-status nil))
+  (setq mew-summary-buffer-process-status nil)
+  (setq mew-summary-buffer-secure-process nil))
 
-(defun mew-net-status (buf status &optional substatus)
+(defun mew-net-status-clear (buf)
+  (when mew-use-net-status
+    (save-excursion
+      (set-buffer buf)
+      (setq mew-summary-buffer-process-status nil)
+      (setq mew-summary-buffer-secure-process nil))))
+
+(defun mew-net-status (buf status &optional substatus secure)
   (when mew-use-net-status
     (save-excursion
       (set-buffer buf)
       (if substatus
 	  (setq mew-summary-buffer-process-status
 		(format " %s:%s" status substatus))
-	(setq mew-summary-buffer-process-status (format " %s" status))))))
+	(setq mew-summary-buffer-process-status (format " %s" status)))
+      (setq mew-summary-buffer-secure-process secure))))
 
-(defun mew-net-status1 (buf dttl dcnt)
+(defun mew-net-status1 (buf dttl dcnt &optional secure)
   (when mew-use-net-status
     (when (<= dcnt dttl)
       (let ((substatus (format "%d/%d" dcnt dttl)))
-	(mew-net-status buf "Deleting" substatus)))))
+	(mew-net-status buf "Deleting" substatus secure)))))
 
 (defvar mew-net-status-percent-size 51200)
 
-(defun mew-net-status2 (buf rttl rcnt siz &optional zero)
+(defun mew-net-status2 (buf rttl rcnt siz &optional zero secure)
   (when mew-use-net-status
     (when (<= rcnt rttl)
       (let ((msiz (string-to-int siz))
@@ -64,13 +102,13 @@
 		 (< msiz mew-net-status-percent-size))
 	    (progn
 	      (setq substatus (format "%d/%d" rcnt rttl))
-	      (mew-net-status buf "Retrieving" substatus))
+	      (mew-net-status buf "Retrieving" substatus secure))
 	  (if (= msiz 0) (setq msiz 1))
 	  (if (< 10000 msiz)
 	      (setq percent (/ bsiz (/ msiz 100)))
 	    (setq percent (/ (* bsiz 100) msiz)))
 	  (setq substatus (format "%d/%d:%02d%%" rcnt rttl percent))
-	  (mew-net-status buf "Retrieving" substatus))))))
+	  (mew-net-status buf "Retrieving" substatus secure))))))
 
 (defvar mew-local-status-unit 10)
 (defvar mew-local-status-threshold 100)
@@ -372,30 +410,21 @@
       (mew-rendezvous mew-summary-buffer-process))))
 
 (defun mew-summary-retrieve (&optional no-flush)
-  "Retrieve messages to +inbox asynchronously.
+  "Retrieve messages to +inbox asynchronously according to
+'mew-mailbox-type'. 
+
+If 'mew-auto-flush-queue' is non-nil, +queue is flushed.
 If called with '\\[universal-argument]', +queue is not flushed."
   (interactive "P")
   (let* ((case mew-case-input)
-	 proto inbox case-inbox mailbox dir)
+	 (inbox (mew-inbox-folder case))
+	 (dir (mew-expand-folder inbox))
+	 (mailbox (mew-mailbox-type case)))
+    (unless (file-directory-p dir)
+      (mew-make-directory dir))
     ;; for mew-summary-exchange-point.
-    (cond
-     ((mew-summary-or-virtual-p)
-      (setq proto (mew-proto-to-inc (mew-summary-folder-name 'ext)))
-      (setq inbox (mew-proto-inbox-folder proto case))
-      (setq case-inbox (mew-canonicalize-case-folder inbox))
-      (setq dir (mew-expand-folder case-inbox))
-      (unless (file-directory-p dir)
-	(mew-make-directory dir))
-      (set-marker mew-summary-inbox-position (point) (current-buffer))
-      (mew-summary-switch-to-folder case-inbox))
-     (t
-      (setq inbox (mew-proto-inbox-folder nil case))
-      (setq case-inbox (mew-canonicalize-case-folder inbox))
-      (setq dir (mew-expand-folder case-inbox))
-      (unless (file-directory-p dir)
-	(mew-make-directory dir))
-      (mew-summary-switch-to-folder case-inbox)
-      (set-marker mew-summary-inbox-position (point) (current-buffer))))
+    (set-marker mew-summary-inbox-position (point) (current-buffer))
+    (mew-summary-switch-to-folder inbox)
     ;; in the inbox
     (when (mew-summary-exclusive-p)
       (mew-window-configure 'summary)
@@ -404,7 +433,39 @@ If called with '\\[universal-argument]', +queue is not flushed."
       (mew-decode-syntax-delete)
       (mew-unhighlight-cursor-line)
       ;;
-      (if (mew-folder-localp inbox) (mew-summary-retrieve-gap case-inbox))
+      (mew-summary-retrieve-gap inbox)
+      ;;
+      (goto-char (point-max))
+      (mew-sinfo-set-start-point (point))
+      (mew-sinfo-set-direction 'down)
+      (cond
+       ((eq mailbox 'pop)
+	(mew-pop-retrieve case 'inc inbox (not no-flush)))
+       ((eq mailbox 'imap)
+	(mew-imap-retrieve case 'inc inbox (not no-flush)))
+       ((eq mailbox 'mbox)
+	(mew-mbox-retrieve case 'inc inbox (not no-flush)))))))
+
+(defun mew-summary-scan-boot (proto case)
+  ;; called by mew()
+  (let* ((inbox (mew-proto-inbox-folder proto case))
+	 (case:inbox (mew-folder-case-folder case inbox))
+	 (dir (mew-expand-folder case:inbox))
+	 mailbox)
+    (unless (file-directory-p dir)
+      (mew-make-directory dir))
+    (mew-summary-switch-to-folder case:inbox)
+    ;; in the inbox
+    ;; for mew-summary-exchange-point.
+    (set-marker mew-summary-inbox-position (point) (current-buffer))
+    (when (mew-summary-exclusive-p)
+      (mew-window-configure 'summary)
+      ;;
+      (mew-current-set nil nil nil)
+      (mew-decode-syntax-delete)
+      (mew-unhighlight-cursor-line)
+      ;;
+      (if (mew-folder-localp inbox) (mew-summary-retrieve-gap case:inbox))
       ;;
       (goto-char (point-max))
       (mew-sinfo-set-start-point (point))
@@ -414,34 +475,29 @@ If called with '\\[universal-argument]', +queue is not flushed."
 	(setq mailbox (mew-mailbox-type case))
 	(cond
 	 ((eq mailbox 'pop)
-	  (mew-pop-retrieve case 'inc case-inbox (not no-flush)))
+	  (mew-pop-retrieve case 'inc inbox))
 	 ((eq mailbox 'imap)
-	  (mew-imap-retrieve case 'inc case-inbox (not no-flush)))
+	  (mew-imap-retrieve case 'inc inbox))
 	 ((eq mailbox 'mbox)
-	  (mew-mbox-retrieve case))))
+	  (mew-mbox-retrieve case 'inc inbox))))
        ((mew-folder-popp inbox)
-	(mew-pop-retrieve case 'scan case-inbox nil 'get-body))
+	(mew-pop-retrieve case 'scan case:inbox nil 'get-body))
        ((mew-folder-imapp inbox)
-	(mew-imap-retrieve case 'scan case-inbox nil 'get-body))
+	(mew-imap-retrieve case 'scan case:inbox nil 'get-body))
        ((mew-folder-nntpp inbox)
-	(mew-nntp-retrieve case 'scan case-inbox nil 'get-body))))))
+	(mew-nntp-retrieve case 'scan case:inbox nil 'get-body))))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; Retrieving messages from mbox
-;;;
-
-(defun mew-mbox-retrieve (case)
+(defun mew-mbox-retrieve (case directive inbox &optional flush)
+  ;; directive is 'inc
   (let ((mbox-command (mew-mbox-command case))
 	(mbox-command-arg (mew-mbox-command-arg case))
-	(inbox (mew-inbox-folder case))
 	opts)
     (if (not (mew-which-exec mbox-command))
 	(message "'%s' not found!" mbox-command)
       (if mbox-command-arg
 	  (setq opts (list "-e" mbox-command "-m" mbox-command-arg))
 	(setq opts (list "-e" mbox-command)))
-      (mew-local-retrieve 'inc inbox opts))))
+      (mew-local-retrieve 'inc inbox flush opts))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -449,17 +505,16 @@ If called with '\\[universal-argument]', +queue is not flushed."
 ;;;
 
 (defun mew-summary-retrieve-message (&optional rev-del)
-  "Retrieve the rest of a truncated('T') message.  
+  "Retrieve the rest of a truncated('T') message.
 
-If you use this command in a LOCAL folder and
-'mew-pop-delete'/'mew-imap-delete' is 't', delete the message from the
-mailbox.
+In a LOCAL folder: a method to retrieve the message is determined by
+'mew-input-case' and 'mew-mailbox-type'. If
+'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the message from
+the mailbox. When executed with '\\[universal-argument]',
+'mew-pop-delete'/'mew-imap-delete' is considered reversed.
 
-If you use this command in a REMOTE folder, the message in the server
-side is always retained.
-
-When executed with '\\[universal-argument]',
-'mew-pop-delete'/'mew-imap-delete' is considered reversed."
+In a REMOTE folder: case and protocol are determined by the folder.
+The message in the server side is always retained."
   (interactive "P")
   (mew-summary-msg
    (mew-summary-only
@@ -470,7 +525,7 @@ When executed with '\\[universal-argument]',
 	       (case (mew-sinfo-get-case))
 	       msg uid siz del rtr rtrs mailbox)
 	  (when (mew-folder-localp folder)
-	    (unless case (setq case mew-case-input))
+	    (setq case mew-case-input)
 	    (setq mailbox (mew-mailbox-type case))
 	    (cond
 	     ((eq mailbox 'pop)
@@ -501,17 +556,16 @@ When executed with '\\[universal-argument]',
 	      (mew-nntp-retrieve case 'get bnm rtrs))))))))))
 
 (defun mew-summary-mark-retrieve-message (&optional rev-del)
-  "Retrieve the rest of truncated('T') messages marked with '*'. 
+  "Retrieve the rest of truncated('T') messages marked with '*'.
 
-If you use this command in a LOCAL folder and
-'mew-pop-delete'/'mew-imap-delete' is 't', delete the message from the
-mailbox. 
+In a LOCAL folder: a method to retrieve the messages is determined by
+'mew-input-case' and 'mew-mailbox-type'.  If
+'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the messages
+from the mailbox.  When executed with '\\[universal-argument]',
+'mew-pop-delete'/'mew-imap-delete' is considered reversed.
 
-If you use this command in a REMOTE folder, the message in the server
-side is always retained.
-
-When executed with '\\[universal-argument]',
-'mew-pop-delete'/'mew-imap-delete' is considered reversed."
+In a REMOTE folder: case and protocol are determined by the folder.
+The messages in the server side is always retained."
   (interactive "P")
   (mew-summary-only
    (let* ((bnm (mew-summary-folder-name 'ext))
@@ -519,7 +573,7 @@ When executed with '\\[universal-argument]',
 	  (case (mew-sinfo-get-case))
 	  msg uid siz del rtr rtrs mailbox)
      (when (mew-folder-localp folder)
-       (unless case (setq case mew-case-input))
+       (setq case mew-case-input)
        (setq mailbox (mew-mailbox-type case))
        (cond
 	((eq mailbox 'pop)
@@ -615,7 +669,7 @@ When executed with '\\[universal-argument]',
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2002 Mew developing team.
+;; Copyright (C) 2002-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
