@@ -218,7 +218,13 @@ and retern (beg . end)."
 
 (defvar mew-mode-line-target "%p")
 (defvar mew-mode-line-format
-  '("[" mew-summary-buffer-left-msgs " more]" (mew-summary-buffer-raw "*")))
+  `("[" mew-summary-buffer-left-msgs " more]"
+    (mew-summary-buffer-raw "*")
+    (mew-summary-buffer-secure-process ,mew-secure-format2)))
+
+(defvar mew-mode-line-process
+  '((mew-summary-buffer-secure-process mew-secure-format)
+    (mew-summary-buffer-process mew-summary-buffer-process-status)))
 
 (defun mew-summary-setup-mode-line ()
   (let ((tgt mew-mode-line-target)
@@ -237,9 +243,7 @@ and retern (beg . end)."
       (setcar (nthcdr pos prev) mew-mode-line-format))
     (or (assq 'mew-summary-buffer-process mode-line-process)
 	(setq mode-line-process
-	      (cons '(mew-summary-buffer-process
-		      mew-summary-buffer-process-status)
-		    mode-line-process)))))
+	      (append mew-mode-line-process mode-line-process)))))
 
 (defun mew-summary-reset-mode-line ()
   (setq mew-summary-buffer-left-msgs  "-")) ;; local variable
@@ -386,20 +390,30 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-jump-top]	Go to the beginning of this Summary mode.
 \\[mew-summary-jump-bottom]	Go to the end of this Summary mode.
 
-\\[mew-summary-retrieve]	Retrieve messages to +inbox asynchronously.
+\\[mew-summary-retrieve]	Retrieve messages to +inbox asynchronously according to
+	'mew-mailbox-type'. 
+	If 'mew-auto-flush-queue' is non-nil, +queue is flushed.
 	If called with '\\[universal-argument]', +queue is not flushed.
 \\[mew-summary-retrieve-message]	Retrieve the rest of a truncated('T') message.
-	If 'mew-pop-delete'/'mew-imap-delete' is 't', delete the message 
-	from the mailbox. When executed with '\\[universal-argument]', 
+	In a LOCAL folder: 'mew-input-case' is used for a case.  If
+	'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the message from
+	the mailbox.  When executed with '\\[universal-argument]',
 	'mew-pop-delete'/'mew-imap-delete' is considered reversed.
+	In a REMOTE folder: case is determined by its folder.  The message in
+	the server side is always retained.
 
 \\[mew-summary-ls]	List this folder asynchronously.
-	If this command is used in a remote folder, messages in its mailbox
-	are cached according to a user specified range.
-	If this command is used in a remote folder and called with
-	'\\[universal-argument]', headers of messages in its mailbox are
-	cached according to a user specified range.
-\\[mew-summary-goto-folder]	Go to the folder which you input.
+	In a LOCAL folder: messages in the local folder are scanned according
+	to the range which you specify.
+	In a REMOTE folder: messages in the server's folder are cached
+	according to the range which you specify. If
+	'mew-pop-header-only'/'mew-imap-header-only'/'mew-nntp-header-only' is
+	non-nil, only headers of messages are cacched. If executed with
+	'\\[universal-argument]', these variables are considered reversed.
+
+\\[mew-summary-goto-folder]	Go to the folder which you specify.  If executed with
+	'\\[universal-argument]', the cursor always goes to the bottom of
+	Summary mode.
 
 \\[mew-summary-send]	Write a message. A new draft is prepared in Draft mode.
 
@@ -468,10 +482,14 @@ The keys that are defined for both Summary mode and Virtual mode are:
 \\[mew-summary-mark-multi]	Change the '*' mark into the '@' mark.
 \\[mew-summary-mark-undo-all]	Unmark all message marked with 'o'/'D'/'X'.
 \\[mew-summary-mark-swap]	Swap the '@' mark and the '*' mark.
-\\[mew-summary-mark-retrieve-message]	Retrieve the rest of truncated('T') messages marked with '*'.
-	If 'mew-pop-delete'/'mew-imap-delete' is 't', delete the message 
-	from the mailbox. When executed with '\\[universal-argument]', 
+
+\\[mew-summary-mark-retrieve-message]	Retrieve the rest of a truncated('T') message marked with '*'.
+	In a LOCAL folder: 'mew-input-case' is used for a case.  If
+	'mew-pop-delete'/'mew-imap-delete' is non-nil, delete the message from
+	the mailbox.  When executed with '\\[universal-argument]',
 	'mew-pop-delete'/'mew-imap-delete' is considered reversed.
+	In a REMOTE folder: case is determined by its folder.  The message in
+	the server side is always retained.
 
 \\[mew-summary-delete]	Put the delete mark(default is 'D') on this
 	message.  This can overlay other marks. When it overlays, the
@@ -559,6 +577,11 @@ The keys that are defined for both Summary mode and Virtual mode are:
 	If called with '\\[universal-argument]', the body of the message
 	(excluding its header) is sent.
 
+\\[mew-summary-cmd-msg]	Executing an external command specifying this message as an
+	argument.
+\\[mew-summary-cmd-msgs]	Executing an external command specifying messages
+	marked with '@' as arguments.
+
 \\[mew-summary-send-message]	If in +queue, send the messages in +queue.
 	If in +postq, post the messages in +postq.
 	If in %queue, process the jobs in %queue.
@@ -650,6 +673,8 @@ folder.
 	to picked messages from multiple folders. Enter a virtual
 	folder name, comma-separated folders, and pick pattern.
 
+\\[mew-summary-mark-virtual]	Making Virtaul mode for messages marked with '*'.
+
 \\[mew-summary-sort]	Sort messages and list them up again.
 	If called with '\\[universal-argument]', sort the region.
 	After sorting, the cursor moves onto the beginning of the buffer
@@ -743,15 +768,14 @@ is equivalent to
   (interactive)
   (mew-kill-buffer)
   (when (and mew-use-other-frame-for-summary (> (length (frame-list)) 1))
-    (let ((buf (mew-buffer-message)))
-      (if (get-buffer buf) (kill-buffer buf)))
+    (mew-remove-buffer (mew-buffer-message))
     (delete-frame)))
 
 (provide 'mew-summary)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
