@@ -499,7 +499,8 @@ in draft buffer.")
     (,mew-message-id:    unstruct   unstruct)
     (,mew-references:    unstruct   unstruct)
     (,mew-in-reply-to:   unstruct   unstruct)
-    (,mew-x-face:	 unstruct   unstruct))
+    (,mew-x-face:	 unstruct   unstruct)
+    (,mew-face:          unstruct   unstruct))
   "(field enc dec)")
 
 (defsubst mew-field-type-for-encoding (key)
@@ -653,6 +654,9 @@ in draft buffer.")
     ("^\\(Mime-Version\\|Lines\\):$" nil)
     ("^From$" nil)
     ("^Status:$" nil)
+    ("^Face:$" nil
+     mew-face-header-private
+     mew-face-header-marginal)
     ("^X-" nil
      mew-face-header-private
      mew-face-header-marginal))
